/*
 * Copyright (C) 2015 Martin Bříza <mbriza@redhat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "platformplugin.h"

QGnomePlatformThemePlugin::QGnomePlatformThemePlugin(QObject *parent)
    : QPlatformThemePlugin(parent)
{
}

QPlatformTheme *QGnomePlatformThemePlugin::create(const QString &key, const QStringList &paramList)
{
    Q_UNUSED(paramList)
    if (key == "gnome" || key == "qgnomeplatform")
        return new QGnomePlatformTheme();
    return nullptr;
}
